/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.storage.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * A bucket.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud Storage API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Bucket extends GenericJson {

  /**
   * Access controls on the bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<BucketAccessControl> acl;

  static {
    // hack to force ProGuard to consider BucketAccessControl used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(BucketAccessControl.class);
  }

  /**
   * The bucket's Cross-Origin Resource Sharing (CORS) configuration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Cors> cors;

  static {
    // hack to force ProGuard to consider Cors used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Cors.class);
  }

  /**
   * Default access controls to apply to new objects when no ACL is provided.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<ObjectAccessControl> defaultObjectAcl;

  static {
    // hack to force ProGuard to consider ObjectAccessControl used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(ObjectAccessControl.class);
  }

  /**
   * HTTP 1.1 Entity tag for the bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID of the bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of item this is. For buckets, this is always storage#bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The bucket's lifecycle configuration. See object lifecycle management for more information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Lifecycle lifecycle;

  /**
   * The location of the bucket. Object data for objects in the bucket resides in physical storage
   * within this region. Typical values are US and EU. Defaults to US. See the developer's guide for
   * the authoritative list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String location;

  /**
   * The bucket's logging configuration, which defines the destination bucket and optional name
   * prefix for the current bucket's logs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Logging logging;

  /**
   * The metadata generation of this bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long metageneration;

  /**
   * The name of the bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The owner of the bucket. This will always be the project team's owner group.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Owner owner;

  /**
   * The URI of this bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The bucket's storage class. This defines how objects in the bucket will be stored and
   * determines the SLA and the cost of storage. Typical values are STANDARD and
   * DURABLE_REDUCED_AVAILABILITY. Defaults to STANDARD. See the developer's guide for the
   * authoritative list.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String storageClass;

  /**
   * Creation time of the bucket in RFC 3339 format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime timeCreated;

  /**
   * The bucket's versioning configuration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Versioning versioning;

  /**
   * The bucket's website configuration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Website website;

  /**
   * Access controls on the bucket.
   * The value returned may be {@code null}.
   */
  public java.util.List<BucketAccessControl> getAcl() {
    return acl;
  }

  /**
   * Access controls on the bucket.
   * The value set may be {@code null}.
   */
  public Bucket setAcl(java.util.List<BucketAccessControl> acl) {
    this.acl = acl;
    return this;
  }

  /**
   * The bucket's Cross-Origin Resource Sharing (CORS) configuration.
   * The value returned may be {@code null}.
   */
  public java.util.List<Cors> getCors() {
    return cors;
  }

  /**
   * The bucket's Cross-Origin Resource Sharing (CORS) configuration.
   * The value set may be {@code null}.
   */
  public Bucket setCors(java.util.List<Cors> cors) {
    this.cors = cors;
    return this;
  }

  /**
   * Default access controls to apply to new objects when no ACL is provided.
   * The value returned may be {@code null}.
   */
  public java.util.List<ObjectAccessControl> getDefaultObjectAcl() {
    return defaultObjectAcl;
  }

  /**
   * Default access controls to apply to new objects when no ACL is provided.
   * The value set may be {@code null}.
   */
  public Bucket setDefaultObjectAcl(java.util.List<ObjectAccessControl> defaultObjectAcl) {
    this.defaultObjectAcl = defaultObjectAcl;
    return this;
  }

  /**
   * HTTP 1.1 Entity tag for the bucket.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * HTTP 1.1 Entity tag for the bucket.
   * The value set may be {@code null}.
   */
  public Bucket setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID of the bucket.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the bucket.
   * The value set may be {@code null}.
   */
  public Bucket setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of item this is. For buckets, this is always storage#bucket.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of item this is. For buckets, this is always storage#bucket.
   * The value set may be {@code null}.
   */
  public Bucket setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The bucket's lifecycle configuration. See object lifecycle management for more information.
   * The value returned may be {@code null}.
   */
  public Lifecycle getLifecycle() {
    return lifecycle;
  }

  /**
   * The bucket's lifecycle configuration. See object lifecycle management for more information.
   * The value set may be {@code null}.
   */
  public Bucket setLifecycle(Lifecycle lifecycle) {
    this.lifecycle = lifecycle;
    return this;
  }

  /**
   * The location of the bucket. Object data for objects in the bucket resides in physical storage
   * within this region. Typical values are US and EU. Defaults to US. See the developer's guide for
   * the authoritative list.
   * The value returned may be {@code null}.
   */
  public String getLocation() {
    return location;
  }

  /**
   * The location of the bucket. Object data for objects in the bucket resides in physical storage
   * within this region. Typical values are US and EU. Defaults to US. See the developer's guide for
   * the authoritative list.
   * The value set may be {@code null}.
   */
  public Bucket setLocation(String location) {
    this.location = location;
    return this;
  }

  /**
   * The bucket's logging configuration, which defines the destination bucket and optional name
   * prefix for the current bucket's logs.
   * The value returned may be {@code null}.
   */
  public Logging getLogging() {
    return logging;
  }

  /**
   * The bucket's logging configuration, which defines the destination bucket and optional name
   * prefix for the current bucket's logs.
   * The value set may be {@code null}.
   */
  public Bucket setLogging(Logging logging) {
    this.logging = logging;
    return this;
  }

  /**
   * The metadata generation of this bucket.
   * The value returned may be {@code null}.
   */
  public Long getMetageneration() {
    return metageneration;
  }

  /**
   * The metadata generation of this bucket.
   * The value set may be {@code null}.
   */
  public Bucket setMetageneration(Long metageneration) {
    this.metageneration = metageneration;
    return this;
  }

  /**
   * The name of the bucket.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the bucket.
   * The value set may be {@code null}.
   */
  public Bucket setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The owner of the bucket. This will always be the project team's owner group.
   * The value returned may be {@code null}.
   */
  public Owner getOwner() {
    return owner;
  }

  /**
   * The owner of the bucket. This will always be the project team's owner group.
   * The value set may be {@code null}.
   */
  public Bucket setOwner(Owner owner) {
    this.owner = owner;
    return this;
  }

  /**
   * The URI of this bucket.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The URI of this bucket.
   * The value set may be {@code null}.
   */
  public Bucket setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * The bucket's storage class. This defines how objects in the bucket will be stored and
   * determines the SLA and the cost of storage. Typical values are STANDARD and
   * DURABLE_REDUCED_AVAILABILITY. Defaults to STANDARD. See the developer's guide for the
   * authoritative list.
   * The value returned may be {@code null}.
   */
  public String getStorageClass() {
    return storageClass;
  }

  /**
   * The bucket's storage class. This defines how objects in the bucket will be stored and
   * determines the SLA and the cost of storage. Typical values are STANDARD and
   * DURABLE_REDUCED_AVAILABILITY. Defaults to STANDARD. See the developer's guide for the
   * authoritative list.
   * The value set may be {@code null}.
   */
  public Bucket setStorageClass(String storageClass) {
    this.storageClass = storageClass;
    return this;
  }

  /**
   * Creation time of the bucket in RFC 3339 format.
   * The value returned may be {@code null}.
   */
  public DateTime getTimeCreated() {
    return timeCreated;
  }

  /**
   * Creation time of the bucket in RFC 3339 format.
   * The value set may be {@code null}.
   */
  public Bucket setTimeCreated(DateTime timeCreated) {
    this.timeCreated = timeCreated;
    return this;
  }

  /**
   * The bucket's versioning configuration.
   * The value returned may be {@code null}.
   */
  public Versioning getVersioning() {
    return versioning;
  }

  /**
   * The bucket's versioning configuration.
   * The value set may be {@code null}.
   */
  public Bucket setVersioning(Versioning versioning) {
    this.versioning = versioning;
    return this;
  }

  /**
   * The bucket's website configuration.
   * The value returned may be {@code null}.
   */
  public Website getWebsite() {
    return website;
  }

  /**
   * The bucket's website configuration.
   * The value set may be {@code null}.
   */
  public Bucket setWebsite(Website website) {
    this.website = website;
    return this;
  }

  /**
   * Model definition for BucketCors.
   */
  public static final class Cors extends GenericJson {

    /**
     * The value, in seconds, to return in the  Access-Control-Max-Age header used in preflight
     * responses.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer maxAgeSeconds;

    /**
     * The list of HTTP methods on which to include CORS response headers, e.g. GET, OPTIONS, POST.
     * Note, "*" is permitted in the list of methods, and means "any method".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> method;

    /**
     * The list of Origins eligible to receive CORS response headers. Note: "*" is permitted in the
     * list of origins, and means "any Origin".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> origin;

    /**
     * The list of HTTP headers other than the simple response headers to give permission for the
     * user-agent to share across domains.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> responseHeader;

    /**
     * The value, in seconds, to return in the  Access-Control-Max-Age header used in preflight
     * responses.
     * The value returned may be {@code null}.
     */
    public Integer getMaxAgeSeconds() {
      return maxAgeSeconds;
    }

    /**
     * The value, in seconds, to return in the  Access-Control-Max-Age header used in preflight
     * responses.
     * The value set may be {@code null}.
     */
    public Cors setMaxAgeSeconds(Integer maxAgeSeconds) {
      this.maxAgeSeconds = maxAgeSeconds;
      return this;
    }

    /**
     * The list of HTTP methods on which to include CORS response headers, e.g. GET, OPTIONS, POST.
     * Note, "*" is permitted in the list of methods, and means "any method".
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getMethod() {
      return method;
    }

    /**
     * The list of HTTP methods on which to include CORS response headers, e.g. GET, OPTIONS, POST.
     * Note, "*" is permitted in the list of methods, and means "any method".
     * The value set may be {@code null}.
     */
    public Cors setMethod(java.util.List<String> method) {
      this.method = method;
      return this;
    }

    /**
     * The list of Origins eligible to receive CORS response headers. Note: "*" is permitted in the
     * list of origins, and means "any Origin".
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getOrigin() {
      return origin;
    }

    /**
     * The list of Origins eligible to receive CORS response headers. Note: "*" is permitted in the
     * list of origins, and means "any Origin".
     * The value set may be {@code null}.
     */
    public Cors setOrigin(java.util.List<String> origin) {
      this.origin = origin;
      return this;
    }

    /**
     * The list of HTTP headers other than the simple response headers to give permission for the
     * user-agent to share across domains.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getResponseHeader() {
      return responseHeader;
    }

    /**
     * The list of HTTP headers other than the simple response headers to give permission for the
     * user-agent to share across domains.
     * The value set may be {@code null}.
     */
    public Cors setResponseHeader(java.util.List<String> responseHeader) {
      this.responseHeader = responseHeader;
      return this;
    }

  }

  /**
   * The bucket's lifecycle configuration. See object lifecycle management for more information.
   */
  public static final class Lifecycle extends GenericJson {

    /**
     * A lifecycle management rule, which is made of an action to take and the condition(s) under
     * which the action will be taken.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Rule> rule;

    static {
      // hack to force ProGuard to consider Rule used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Rule.class);
    }

    /**
     * A lifecycle management rule, which is made of an action to take and the condition(s) under
     * which the action will be taken.
     * The value returned may be {@code null}.
     */
    public java.util.List<Rule> getRule() {
      return rule;
    }

    /**
     * A lifecycle management rule, which is made of an action to take and the condition(s) under
     * which the action will be taken.
     * The value set may be {@code null}.
     */
    public Lifecycle setRule(java.util.List<Rule> rule) {
      this.rule = rule;
      return this;
    }

    /**
     * Model definition for BucketLifecycleRule.
     */
    public static final class Rule extends GenericJson {

      /**
       * The action to take.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Action action;

      /**
       * The condition(s) under which the action will be taken.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Condition condition;

      /**
       * The action to take.
       * The value returned may be {@code null}.
       */
      public Action getAction() {
        return action;
      }

      /**
       * The action to take.
       * The value set may be {@code null}.
       */
      public Rule setAction(Action action) {
        this.action = action;
        return this;
      }

      /**
       * The condition(s) under which the action will be taken.
       * The value returned may be {@code null}.
       */
      public Condition getCondition() {
        return condition;
      }

      /**
       * The condition(s) under which the action will be taken.
       * The value set may be {@code null}.
       */
      public Rule setCondition(Condition condition) {
        this.condition = condition;
        return this;
      }

      /**
       * The action to take.
       */
      public static final class Action extends GenericJson {

        /**
         * Type of the action, e.g. Delete.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String type;

        /**
         * Type of the action, e.g. Delete.
         * The value returned may be {@code null}.
         */
        public String getType() {
          return type;
        }

        /**
         * Type of the action, e.g. Delete.
         * The value set may be {@code null}.
         */
        public Action setType(String type) {
          this.type = type;
          return this;
        }

      }
      /**
       * The condition(s) under which the action will be taken.
       */
      public static final class Condition extends GenericJson {

        /**
         * Age of an object (in days). This condition is satisfied when an object reaches the specified
         * age.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Integer age;

        /**
         * A date in RFC 3339 format with only the date part, e.g. "2013-01-15". This condition is
         * satisfied when an object is created before midnight of the specified date in UTC.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private DateTime createdBefore;

        /**
         * Relevant only for versioned objects. If the value is true, this condition matches live objects;
         * if the value is false, it matches archived objects.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Boolean isLive;

        /**
         * Relevant only for versioned objects. If the value is N, this condition is satisfied when there
         * are at least N versions (including the live version) newer than this version of the object.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Integer numNewerVersions;

        /**
         * Age of an object (in days). This condition is satisfied when an object reaches the specified
         * age.
         * The value returned may be {@code null}.
         */
        public Integer getAge() {
          return age;
        }

        /**
         * Age of an object (in days). This condition is satisfied when an object reaches the specified
         * age.
         * The value set may be {@code null}.
         */
        public Condition setAge(Integer age) {
          this.age = age;
          return this;
        }

        /**
         * A date in RFC 3339 format with only the date part, e.g. "2013-01-15". This condition is
         * satisfied when an object is created before midnight of the specified date in UTC.
         * The value returned may be {@code null}.
         */
        public DateTime getCreatedBefore() {
          return createdBefore;
        }

        /**
         * A date in RFC 3339 format with only the date part, e.g. "2013-01-15". This condition is
         * satisfied when an object is created before midnight of the specified date in UTC.
         * The value set may be {@code null}.
         */
        public Condition setCreatedBefore(DateTime createdBefore) {
          this.createdBefore = createdBefore;
          return this;
        }

        /**
         * Relevant only for versioned objects. If the value is true, this condition matches live objects;
         * if the value is false, it matches archived objects.
         * The value returned may be {@code null}.
         */
        public Boolean getIsLive() {
          return isLive;
        }

        /**
         * Relevant only for versioned objects. If the value is true, this condition matches live objects;
         * if the value is false, it matches archived objects.
         * The value set may be {@code null}.
         */
        public Condition setIsLive(Boolean isLive) {
          this.isLive = isLive;
          return this;
        }

        /**
         * Relevant only for versioned objects. If the value is N, this condition is satisfied when there
         * are at least N versions (including the live version) newer than this version of the object.
         * The value returned may be {@code null}.
         */
        public Integer getNumNewerVersions() {
          return numNewerVersions;
        }

        /**
         * Relevant only for versioned objects. If the value is N, this condition is satisfied when there
         * are at least N versions (including the live version) newer than this version of the object.
         * The value set may be {@code null}.
         */
        public Condition setNumNewerVersions(Integer numNewerVersions) {
          this.numNewerVersions = numNewerVersions;
          return this;
        }

      }
    }
  }

  /**
   * The bucket's logging configuration, which defines the destination bucket and optional name prefix
   * for the current bucket's logs.
   */
  public static final class Logging extends GenericJson {

    /**
     * The destination bucket where the current bucket's logs should be placed.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String logBucket;

    /**
     * A prefix for log object names.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String logObjectPrefix;

    /**
     * The destination bucket where the current bucket's logs should be placed.
     * The value returned may be {@code null}.
     */
    public String getLogBucket() {
      return logBucket;
    }

    /**
     * The destination bucket where the current bucket's logs should be placed.
     * The value set may be {@code null}.
     */
    public Logging setLogBucket(String logBucket) {
      this.logBucket = logBucket;
      return this;
    }

    /**
     * A prefix for log object names.
     * The value returned may be {@code null}.
     */
    public String getLogObjectPrefix() {
      return logObjectPrefix;
    }

    /**
     * A prefix for log object names.
     * The value set may be {@code null}.
     */
    public Logging setLogObjectPrefix(String logObjectPrefix) {
      this.logObjectPrefix = logObjectPrefix;
      return this;
    }

  }

  /**
   * The owner of the bucket. This will always be the project team's owner group.
   */
  public static final class Owner extends GenericJson {

    /**
     * The entity, in the form group-groupId.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String entity;

    /**
     * The ID for the entity.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String entityId;

    /**
     * The entity, in the form group-groupId.
     * The value returned may be {@code null}.
     */
    public String getEntity() {
      return entity;
    }

    /**
     * The entity, in the form group-groupId.
     * The value set may be {@code null}.
     */
    public Owner setEntity(String entity) {
      this.entity = entity;
      return this;
    }

    /**
     * The ID for the entity.
     * The value returned may be {@code null}.
     */
    public String getEntityId() {
      return entityId;
    }

    /**
     * The ID for the entity.
     * The value set may be {@code null}.
     */
    public Owner setEntityId(String entityId) {
      this.entityId = entityId;
      return this;
    }

  }

  /**
   * The bucket's versioning configuration.
   */
  public static final class Versioning extends GenericJson {

    /**
     * While set to true, versioning is fully enabled for this bucket.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean enabled;

    /**
     * While set to true, versioning is fully enabled for this bucket.
     * The value returned may be {@code null}.
     */
    public Boolean getEnabled() {
      return enabled;
    }

    /**
     * While set to true, versioning is fully enabled for this bucket.
     * The value set may be {@code null}.
     */
    public Versioning setEnabled(Boolean enabled) {
      this.enabled = enabled;
      return this;
    }

  }

  /**
   * The bucket's website configuration.
   */
  public static final class Website extends GenericJson {

    /**
     * Behaves as the bucket's directory index where missing objects are treated as potential
     * directories.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String mainPageSuffix;

    /**
     * The custom object to return when a requested resource is not found.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String notFoundPage;

    /**
     * Behaves as the bucket's directory index where missing objects are treated as potential
     * directories.
     * The value returned may be {@code null}.
     */
    public String getMainPageSuffix() {
      return mainPageSuffix;
    }

    /**
     * Behaves as the bucket's directory index where missing objects are treated as potential
     * directories.
     * The value set may be {@code null}.
     */
    public Website setMainPageSuffix(String mainPageSuffix) {
      this.mainPageSuffix = mainPageSuffix;
      return this;
    }

    /**
     * The custom object to return when a requested resource is not found.
     * The value returned may be {@code null}.
     */
    public String getNotFoundPage() {
      return notFoundPage;
    }

    /**
     * The custom object to return when a requested resource is not found.
     * The value set may be {@code null}.
     */
    public Website setNotFoundPage(String notFoundPage) {
      this.notFoundPage = notFoundPage;
      return this;
    }

  }
}
