/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.storage.model;

import com.google.api.client.json.GenericJson;

/**
 * An access-control entry.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud Storage API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class BucketAccessControl extends GenericJson {

  /**
   * The name of the bucket.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bucket;

  /**
   * The domain associated with the entity, if any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String domain;

  /**
   * The email address associated with the entity, if any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String email;

  /**
   * The entity holding the permission, in one of the following forms: - user-userId  - user-email
   * - group-groupId  - group-email  - domain-domain  - allUsers  - allAuthenticatedUsers Examples:
   * - The user liz@example.com would be user-liz@example.com.  - The group example@googlegroups.com
   * would be group-example@googlegroups.com.  - To refer to all members of the Google Apps for
   * Business domain example.com, the entity would be domain-example.com.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String entity;

  /**
   * The ID for the entity, if any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String entityId;

  /**
   * HTTP 1.1 Entity tag for the access-control entry.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID of the access-control entry.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind of item this is. For bucket access control entries, this is always
   * storage#bucketAccessControl.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The access permission for the entity. Can be READER, WRITER, or OWNER.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String role;

  /**
   * The link to this access-control entry.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The name of the bucket.
   * The value returned may be {@code null}.
   */
  public String getBucket() {
    return bucket;
  }

  /**
   * The name of the bucket.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setBucket(String bucket) {
    this.bucket = bucket;
    return this;
  }

  /**
   * The domain associated with the entity, if any.
   * The value returned may be {@code null}.
   */
  public String getDomain() {
    return domain;
  }

  /**
   * The domain associated with the entity, if any.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setDomain(String domain) {
    this.domain = domain;
    return this;
  }

  /**
   * The email address associated with the entity, if any.
   * The value returned may be {@code null}.
   */
  public String getEmail() {
    return email;
  }

  /**
   * The email address associated with the entity, if any.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setEmail(String email) {
    this.email = email;
    return this;
  }

  /**
   * The entity holding the permission, in one of the following forms: - user-userId  - user-email
   * - group-groupId  - group-email  - domain-domain  - allUsers  - allAuthenticatedUsers Examples:
   * - The user liz@example.com would be user-liz@example.com.  - The group example@googlegroups.com
   * would be group-example@googlegroups.com.  - To refer to all members of the Google Apps for
   * Business domain example.com, the entity would be domain-example.com.
   * The value returned may be {@code null}.
   */
  public String getEntity() {
    return entity;
  }

  /**
   * The entity holding the permission, in one of the following forms: - user-userId  - user-email
   * - group-groupId  - group-email  - domain-domain  - allUsers  - allAuthenticatedUsers Examples:
   * - The user liz@example.com would be user-liz@example.com.  - The group example@googlegroups.com
   * would be group-example@googlegroups.com.  - To refer to all members of the Google Apps for
   * Business domain example.com, the entity would be domain-example.com.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setEntity(String entity) {
    this.entity = entity;
    return this;
  }

  /**
   * The ID for the entity, if any.
   * The value returned may be {@code null}.
   */
  public String getEntityId() {
    return entityId;
  }

  /**
   * The ID for the entity, if any.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setEntityId(String entityId) {
    this.entityId = entityId;
    return this;
  }

  /**
   * HTTP 1.1 Entity tag for the access-control entry.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * HTTP 1.1 Entity tag for the access-control entry.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID of the access-control entry.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the access-control entry.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of item this is. For bucket access control entries, this is always
   * storage#bucketAccessControl.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of item this is. For bucket access control entries, this is always
   * storage#bucketAccessControl.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The access permission for the entity. Can be READER, WRITER, or OWNER.
   * The value returned may be {@code null}.
   */
  public String getRole() {
    return role;
  }

  /**
   * The access permission for the entity. Can be READER, WRITER, or OWNER.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setRole(String role) {
    this.role = role;
    return this;
  }

  /**
   * The link to this access-control entry.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * The link to this access-control entry.
   * The value set may be {@code null}.
   */
  public BucketAccessControl setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

}
